import { APIConnector, RequestState, QueryConfig, ResponseState, AutocompleteQueryConfig, AutocompleteResponseState } from '@elastic/search-ui';
import { estypes } from '@elastic/elasticsearch';

type SearchRequest = estypes.SearchRequest;
type SearchResponse = estypes.SearchResponse<Record<string, unknown>>;
type EngineRouteFn = (host: string, engineName: string) => string;
interface Transporter {
    performRequest(requestBody: SearchRequest): Promise<SearchResponse>;
}
type ConnectionOptions = {
    host: string;
    engineName: string;
    apiKey: string;
};

declare class EngineConnector implements APIConnector {
    private config;
    private transporter;
    constructor(config: ConnectionOptions | Transporter);
    onResultClick(): void;
    onAutocompleteResultClick(): void;
    onSearch(state: RequestState, queryConfig: QueryConfig): Promise<ResponseState>;
    onAutocomplete(state: RequestState, queryConfig: AutocompleteQueryConfig): Promise<AutocompleteResponseState>;
}

export { type ConnectionOptions, type EngineRouteFn, type SearchRequest, type SearchResponse, type Transporter, EngineConnector as default };
